Test for funnel plot asymmetry.
metabias(x, ...)an object of class "meta.nsue", or of other classes in other meta-analytic packages (e.g. "meta").
other arguments.
The function metabias is generic. See metabias.meta.nsue for testing for funnel plot asymmetry for "meta.nsue" objects, or other methods from other meta-analytic packages (e.g. metabias.meta).
metabias.meta.nsue for testing for funnel plot asymmetry for "meta.nsue" objects.
funnel for plotting funnel plots.
meta for conducting a meta-analysis.
metalm for fitting meta-analytic models.